document.addEventListener('DOMContentLoaded', function() {
  // Form submission
  const foodForm = document.getElementById('food-form');
  const foodList = document.getElementById('recent-foods');
  
  if (foodForm) {
    foodForm.addEventListener('submit', function(e) {
      e.preventDefault();
      
      const foodName = document.getElementById('food-name').value;
      const foodCalories = document.getElementById('food-calories').value;
      
      if (foodName && foodCalories) {
        addFoodItem(foodName, foodCalories);
        foodForm.reset();
      }
    });
  }
  
  // Add food item to list
  function addFoodItem(name, calories) {
    const li = document.createElement('li');
    li.className = 'food-item';
    
    li.innerHTML = `
      <span>${name}</span>
      <span>${calories} cal</span>
      <button class="delete-btn">×</button>
    `;
    
    foodList.prepend(li);
    
    // Add delete functionality
    const deleteBtn = li.querySelector('.delete-btn');
    deleteBtn.addEventListener('click', function() {
      li.remove();
    });
  }
  
  // Initialize chart
  const chartCanvas = document.getElementById('calorie-chart');
  if (chartCanvas) {
    const ctx = chartCanvas.getContext('2d');
    
    // Sample data - in a real app this would come from your data
    const chart = new Chart(ctx, {
      type: 'line',
      data: {
        labels: ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun'],
        datasets: [{
          label: 'Calories',
          data: [1800, 1950, 2100, 1850, 2200, 2400, 2000],
          borderColor: '#4CAF50',
          backgroundColor: 'rgba(76, 175, 80, 0.1)',
          fill: true,
          tension: 0.4
        }]
      },
      options: {
        responsive: true,
        plugins: {
          legend: {
            position: 'top',
          },
        },
        scales: {
          y: {
            beginAtZero: false
          }
        }
      }
    });
  }
  
  // Food card click handler
  const foodCards = document.querySelectorAll('.food-card');
  foodCards.forEach(card => {
    card.addEventListener('click', function() {
      const foodName = this.querySelector('h3').textContent;
      const calories = this.querySelector('p').textContent.match(/\d+/)[0];
      
      document.getElementById('food-name').value = foodName;
      document.getElementById('food-calories').value = calories;
      
      // Scroll to form
      document.getElementById('dashboard').scrollIntoView({
        behavior: 'smooth'
      });
    });
  });
  
  // Delete button handlers for existing items
  const deleteButtons = document.querySelectorAll('.delete-btn');
  deleteButtons.forEach(btn => {
    btn.addEventListener('click', function() {
      this.parentElement.remove();
    });
  });
});